package com.kexun.controller;


import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.kexun.common.utils.Result;
import com.kexun.entity.ReportFileEntity;
import com.kexun.service.ReportFileService;
import com.kexun.service.impl.FileServiceImpl;
import com.kexun.utils.DateUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.io.*;
import java.nio.file.Files;
import java.util.Base64;
import java.util.Date;
import java.util.List;
import java.util.Map;

@RestController
@RequestMapping("/admin/report")
@Slf4j
public class ReportFileController {

    /**
     * 文件目录，解析后的文件目录
     */
    @Value("${report.file.xmlTargetPath}")
    private String xmlTargetPath;
    /**
     * 模型文件目标文件
     */
    @Value("${report.file.modelTargetPath}")
    private String modelPath;
    /**
     * 存放JSON文件路径
     */
    @Value("${report.file.jsonTargetPath}")
    private String jsonTargetPath;

    @Autowired
    private ReportFileService reportFileService;
    @Autowired
    FileServiceImpl fileService;


    /**
     * 查询文件列表
     * @param businessNum
     * @return
     */
    @GetMapping("reportFileList")
    public Result businessToDoList(@RequestParam String businessNum) {
        JSONObject resJson = new JSONObject();
        List<ReportFileEntity> list = reportFileService.queryFileByNum(businessNum);
        resJson.put("report_file_list", list);

        return Result.success("ok", resJson);
    }

    /**
     * 文件上传
     *
     * @param file
     * @param params
     * @return
     */
    @PostMapping("/uploadFile")
    public Result uploadModelFile(@RequestParam MultipartFile file, @RequestParam Map<String, String> params) {
        if (params.isEmpty()) {
            return Result.error("-1", "参数为空！");
        } else {
            String headInfId = params.get("headInfId");
            String modelType = params.get("modelType");
            String businessNum = params.get("businessNum");
            if (headInfId != null && !headInfId.equals("")) {
                fileService.saveAndUploadFile(file,Long.valueOf(headInfId),modelType,businessNum);
            }else {
                return Result.error("-1", "参数为空！");
            }
        }
        return Result.success();
    }
    /**
     * xml及json文件下载
     *
     * @param filename
     * @return
     * @throws IOException
     */
    @GetMapping("/download/{path}/{filename}")
    public Result downloadFile(@PathVariable("path") String path, @PathVariable("filename") String filename) throws IOException {

        String downFilePath = xmlTargetPath = xmlTargetPath + path + File.separator + filename;
        if (filename.endsWith(".txt")) {
            downFilePath = jsonTargetPath + path + File.separator + filename;
        }
        File file = new File(downFilePath);
        if (file.exists()) {
            byte[] fileContent = Files.readAllBytes(file.toPath());
            String base64 = Base64.getEncoder().encodeToString(fileContent);
            JSONObject resJson = new JSONObject();
            resJson.put("file", base64);
            return Result.success("ok", resJson);
        } else {
            return Result.error("文件不存在!");
        }

    }
    /**
     * 文件下载
     * @param response
     * @param idList
     * @return
     */
    @PostMapping("file/downLoad")
    public void download(HttpServletResponse response, @RequestBody List<String> idList){
        reportFileService.downLoadFile(response,idList);
    }

    /**
     * 模型文件下载
     *
     * @param modname
     * @return
     * @throws IOException
     */
    @GetMapping("/downloadMod/{path}/{modname}")
    public Result downloadMod(@PathVariable("path") String path, @PathVariable("modname") String modname) throws IOException {
        String downFilePath = modelPath + path + File.separator + modname;
        File file = new File(downFilePath);
        if (file.exists()) {
            byte[] fileContent = Files.readAllBytes(file.toPath());
            String base64 = Base64.getEncoder().encodeToString(fileContent);
            JSONObject resJson = new JSONObject();
            resJson.put("file", base64);
            return Result.success("ok", resJson);
        } else {
            return Result.error("文件不存在!");
        }

    }

    /**
     * 文件删除
     *
     * @param json
     * @return
     */
    @PostMapping("del")
    public Result del(@RequestBody String json) {
        JSONObject req = JSON.parseObject(json);
        String id = req.getString("id");
        if (!StringUtils.isEmpty(id)) {
            ReportFileEntity reportFileEntity = reportFileService.getById(id);
            if (reportFileEntity != null) {
                reportFileService.removeById(id);
            } else {
                return Result.error(-1, "操作id有误");
            }
        } else {
            return Result.error(-1, "操作有误，id不能为空");
        }
        return Result.success();
    }


    /**
     * 文件上传
     * 原来的逻辑是新增，2024.1.2之后改为修改 如果没有文件，改为新增，方法需要重写
     * 目前仍需改：若已有文件，需将原有数据删除
     *
     * @param json
     * @return
     */
    @PostMapping("fileReportAdd")
    public Result fileReportAdd(@RequestBody String json) {
        JSONObject req = JSON.parseObject(json);
        long headInfId = Long.valueOf(req.getString("headInfId"));
        long businessId = Long.valueOf(req.getString("businessId"));
        String s = req.getString("fileNameTxt");
        ReportFileEntity reportFileEntity = reportFileService.findByHeadInfId(headInfId);
        String date = DateUtils.format(new Date(), DateUtils.YYYYMMDD);
        if (reportFileEntity == null) {
            reportFileEntity = new ReportFileEntity();
            reportFileEntity.setHeadInfId(headInfId);
            reportFileEntity.setRptNo(req.getString("rptNo"));
            reportFileEntity.setBusinessId(businessId);
            reportFileEntity.setBusinessNum(req.getString("businessNum"));
            if (req.getString("fileNameXml") == "1") {
                //reportFileEntity.setFileNameXml(req.getString("file_name"));
            } else if (req.getString("fileNameTxt") == "1") {
                // reportFileEntity.setFileNameTxt(req.getString("file_name"));
            } else {
                //reportFileEntity.setFileNameModel(req.getString("file_name"));
            }
        }

        reportFileService.saveOrUpdate(reportFileEntity);
        return Result.success();
    }
}
