package com.kexun.enums;

import lombok.AllArgsConstructor;
import lombok.Getter;

/**
 * Description:文件类型
 * 文件类型0-源文件:1-解析后xml文件;2-解析后的json文件;3-模型文件
 *
 * @author lgs
 * @date 2024/01/22
 */
@AllArgsConstructor
@Getter
public enum FileTypeEnum {

    /**
     * 0-源文件
     */
    SOURCE("0","源文件"),

    /**
     * 1-解析后xml文件
     */
    XML("1","解析结果-xml"),

    /**
     * 2-解析后的json文件
     */
    JSON("2","解析结果-json"),

    /**
     * 3-模型文件
     */
    MODEL("3","模型文件");

    /**
     * 类别码
     */
    private String code;

    /**
     * 类别名称
     */
    private String name;

    /**
     * 根据code查找
     * @param code 枚举code
     * @return 枚举对象
     */
    public static FileTypeEnum findEnumByCode(String code) {
        for (FileTypeEnum statusEnum : FileTypeEnum.values()) {
            if (statusEnum.getCode().equals(code)) {
                //如果需要直接返回name则更改返回类型为String,return statusEnum.name;
                return statusEnum;
            }
        }
        throw new IllegalArgumentException("code is invalid");
    }

    /**
     * 根据name查找
     * @param name 枚举name
     * @return 枚举对象
     */
    public static FileTypeEnum findEnumByName(String name) {
        for (FileTypeEnum statusEnum : FileTypeEnum.values()) {
            if (statusEnum.getName().equals(name)) {
                //如果需要直接返回code则更改返回类型为String,return statusEnum.code;
                return statusEnum;
            }
        }
        throw new IllegalArgumentException("name is invalid");
    }
}
