package com.kexun.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.kexun.entity.ReportFileEntity;
import com.kexun.enums.FileTypeEnum;
import com.kexun.mapper.ReportFileMapper;
import com.kexun.service.ReportFileService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.OutputStream;
import java.net.URLEncoder;
import java.nio.file.Files;
import java.util.List;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;

/**
 * 报文文件服务Service
 */
@Service
@Slf4j
public class ReportFileServiceImpl extends ServiceImpl<ReportFileMapper, ReportFileEntity>
        implements ReportFileService {

    @Resource
    ReportFileMapper reportFileMapper;

    /**
     * 文件目录，解析后的文件目录
     */
    @Value("${report.file.xmlTargetPath}")
    private String xmlTargetPath;

    /**
     * 模型文件目标文件
     */
    @Value("${report.file.modelTargetPath}")
    private String modelTargetPath;

    /**
     * 存放JSON文件路径
     */
    @Value("${report.file.jsonTargetPath}")
    private String jsonTargetPath;

    @Override
    public List<ReportFileEntity> queryFileByNum(String businessNum) {
        List<ReportFileEntity> l = reportFileMapper.queryFileByNum(businessNum);
        for (ReportFileEntity reportFileEntity : l) {

        }
        return l;
    }

    @Override
    public ReportFileEntity findByHeadInfId(long headInfId) {
        QueryWrapper<ReportFileEntity> wrapper = new QueryWrapper<ReportFileEntity>().eq("head_inf_id", headInfId);
        return getOne(wrapper);
    }


    /**
     * 文件下载
     *
     * @param response
     * @param idList
     */
    @Override
    public void downLoadFile(HttpServletResponse response, List<String> idList) {
        //根据idList查询report_file表数据
        List<ReportFileEntity> reportFileEntities = this.listByIds(idList);
        File zipFile = new File(System.currentTimeMillis() + ".zip");
        ZipOutputStream zipOutputStream = null;
        try {
            zipOutputStream = new ZipOutputStream(new FileOutputStream(zipFile));
            for (ReportFileEntity reportFileEntity : reportFileEntities) {
                String filePath = reportFileEntity.getFilePath();
                String fileType = reportFileEntity.getFileType();
                if (fileType.equals(FileTypeEnum.XML.getCode())) {
                    filePath = xmlTargetPath + filePath;
                } else if (fileType.equals(FileTypeEnum.JSON.getCode())) {
                    filePath = jsonTargetPath + filePath;
                } else if (fileType.equals(FileTypeEnum.MODEL.getCode())) {
                    filePath = modelTargetPath + filePath;
                }
                File file = new File(filePath);
                if (file.exists()) {
                    byte[] bytes = new byte[4096];
                    ZipEntry entry = new ZipEntry(file.getName());
                    zipOutputStream.putNextEntry(entry);
                    FileInputStream fileInputStream = new FileInputStream(file);
                    int length;
                    while((length = fileInputStream.read(bytes)) > 0) {
                        zipOutputStream.write(bytes, 0, length);
                    }
                    zipOutputStream.closeEntry();
                    fileInputStream.close();
                } else {
                    log.error("文件找不到，所在路径为{}", filePath);
                }
            }
            //注意，这行代码不能放到下一行代码之后，否则最后一个写入的文件会为空
            zipOutputStream.close();
            byte[] bytes = Files.readAllBytes(zipFile.toPath());
            zipFile.delete();
            response.setContentType("application/octet-stream; charset=utf-8");
            response.setCharacterEncoding("utf8");
            response.setHeader("Content-Disposition", "attachment; filename=" + URLEncoder.encode(zipFile.getName(), "UTF-8"));
            response.setHeader("Pragma", "public");
            response.setHeader("Cache-Control", "no-store");
            response.addHeader("Cache-Control", "max-age=0");
            OutputStream outputStream = response.getOutputStream();
            outputStream.write(bytes);
            response.flushBuffer();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

}




