package com.kexun.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.kexun.entity.ReportInfo;
import com.kexun.enums.ReportStatusEnum;
import com.kexun.mapper.ReportInfoMapper;
import com.kexun.model.dto.ReportInfoDTO;
import com.kexun.model.ro.ReportInfoRO;
import com.kexun.service.ReportInfoService;
import lombok.extern.slf4j.Slf4j;
import org.omg.CORBA.IRObject;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * <p>
 * 报文信息 服务实现类
 * </p>
 *
 * @author lgs
 * @since 2023-05-10
 */
@Service
@Slf4j
public class ReportInfoServiceImpl extends ServiceImpl<ReportInfoMapper, ReportInfo> implements ReportInfoService {

    @Autowired
    private ReportInfoMapper reportInfoMapper;

    /**
     * 保存报文信息
     *
     * @param reportInfo
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void saveReportInfo(ReportInfo reportInfo) {
        //根据business_id查询是否存在，存在的话，执行update语句
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("business_id", reportInfo.getBusinessId());
        ReportInfo reportInfoResult = super.getOne(queryWrapper);
        if (reportInfoResult != null) {
            reportInfo.setId(reportInfoResult.getId());
        }
        super.saveOrUpdate(reportInfo);
    }


    @Override
    @Transactional(rollbackFor = Exception.class)
    public void updateReportInfo(ReportInfoDTO reportInfoDTO) {
        reportInfoMapper.updateReportInfo(reportInfoDTO);
    }

    /**
     * 修改状态
     * @param status
     * @param id
     */
    @Override
    public void updateReportInfoStatus(String status, Long id) {
        reportInfoMapper.updateReportInfoStatus(status,id);
    }

    /**
     * 按条件查询报文信息
     *
     * @param reportInfoDTO
     * @return
     */
    @Override
    public List<ReportInfo> listReportInfo(ReportInfoDTO reportInfoDTO) {
        QueryWrapper queryWrapper = new QueryWrapper();
        if (reportInfoDTO.getStatus() != null) {
            queryWrapper.eq("status", reportInfoDTO.getStatus());
        } else {
            queryWrapper.eq("status", ReportStatusEnum.NO_PRASE.getValue());
        }
        List<ReportInfo> list = reportInfoMapper.selectList(queryWrapper);
        return list;
    }

    /**
     * 根据主键查询报文信息
     *
     * @param id
     * @return
     */
    public ReportInfo getReportInfo(Long id) {
        return reportInfoMapper.selectById(id);
    }


}
