package com.kexun.service.xml;

import com.kexun.constant.BaseConsts;
import com.kexun.entity.*;
import com.kexun.model.dto.CommonParam;
import com.kexun.model.xml.IXmlBase;
import com.kexun.model.xml.trs.*;
import com.kexun.service.*;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * Description:信贷交易明细信息
 *
 * @author lgs
 * @date 2023/06/12
 */
@Service
public class TrsInfHandlerService implements IHandleXmlBaseService {

    @Autowired
    private TrsBaseService trsBaseService;
    @Autowired
    private TrsLateService trsLateService;
    @Autowired
    private TrsLateMonthService trsLateMonthService;
    @Autowired
    private TrsFiveYearService trsFiveYearService;
    @Autowired
    private TrsSpecService trsSpecService;
    @Autowired
    private TrsSpecEvtService trsSpecEvtService;
    @Autowired
    private TrsSpecPrdService trsSpecPrdService;
    @Autowired
    private TrsFiveYearDetailService trsFiveYearDetailService;

    @Override
    public void handleXmlSgmt(CommonParam commonParam, IXmlBase reportXmlBase) {
        /**
         * 处理思路：
         * 1、通过reportXmlBase 得到各个信息段的数据
         * 2、通过commonParam得到对应的账号类别，进行保存到信贷交易相关的表中
         * 3、一共8张表；cr_trs_base,cr_trs_late,cr_trs_late_month,cr_trs_five_year,cr_trs_five_year_detail
         * cr_trs_spec,cr_trs_spec_evt,cr_trs_spec_prd
         */
        if (reportXmlBase instanceof NoLoopAcctTrsInf) {
            Map<String, String> nodeMap = commonParam.getNodeMap();
            String acct_type = nodeMap.get(BaseConsts.ACC_TYPE_KEY);
            NoLoopAcctTrsInf noLoopAcctTrsInf = (NoLoopAcctTrsInf) reportXmlBase;
            List<TrsAcctInf> trsAcctInfList = noLoopAcctTrsInf.getTrsAcctInfList();
            for (TrsAcctInf trsAcctInf : trsAcctInfList) {
                //基本信息
                TrsBase trsBase = trsAcctInf.getTrsBase();
                if (null != trsBase) {
                    TrsBaseEntity trsBaseEntity = new TrsBaseEntity();
                    BeanUtils.copyProperties(trsBase, trsBaseEntity);
                    trsBaseEntity.setName(commonParam.getName());
                    trsBaseEntity.setIdNum(commonParam.getIdNum());
                    trsBaseEntity.setHeadInfId(commonParam.getHeadInfId());
                    trsBaseEntity.setRptNo(commonParam.getRptNo());
                    trsBaseEntity.setAcctType(acct_type);
                    trsBaseService.save(trsBaseEntity);
                }
                //最新表现信息
                TrsLate trsLate = trsAcctInf.getTrsLate();
                if (null != trsLate) {
                    TrsLateEntity trsLateEntity = new TrsLateEntity();
                    BeanUtils.copyProperties(trsLate, trsLateEntity);
                    trsLateEntity.setName(commonParam.getName());
                    trsLateEntity.setIdNum(commonParam.getIdNum());
                    trsLateEntity.setHeadInfId(commonParam.getHeadInfId());
                    trsLateEntity.setRptNo(commonParam.getRptNo());
                    trsLateService.save(trsLateEntity);
                }
                //最近一次月度表现信息
                TrsLateMonth trsLateMonth = trsAcctInf.getTrsLateMonth();
                if (null != trsLateMonth) {
                    TrsLateMonthEntity trsLateMonthEntity = new TrsLateMonthEntity();
                    BeanUtils.copyProperties(trsLateMonth, trsLateMonthEntity);
                    trsLateMonthEntity.setName(commonParam.getName());
                    trsLateMonthEntity.setIdNum(commonParam.getIdNum());
                    trsLateMonthEntity.setHeadInfId(commonParam.getHeadInfId());
                    trsLateMonthEntity.setRptNo(commonParam.getRptNo());
                    trsLateMonthService.save(trsLateMonthEntity);
                }
                //最近5年内历史表现信息
                TrsFiveYear trsFiveYear = trsAcctInf.getTrsFiveYear();
                if (null != trsFiveYear) {
                    TrsFiveYearEntity trsFiveYearEntity = new TrsFiveYearEntity();
                    BeanUtils.copyProperties(trsFiveYear, trsFiveYearEntity);
                    trsFiveYearEntity.setName(commonParam.getName());
                    trsFiveYearEntity.setIdNum(commonParam.getIdNum());
                    trsFiveYearEntity.setHeadInfId(commonParam.getHeadInfId());
                    trsFiveYearEntity.setRptNo(commonParam.getRptNo());
                    trsFiveYearService.save(trsFiveYearEntity);
                    //交易明细
                    TrsFiveYearInf trsFiveYearInf = trsFiveYear.getTrsFiveYearInf();
                    if (null != trsFiveYearInf) {
                        List<TrsFiveYearDetail> trsFiveYearDetailList = trsFiveYearInf.getTrsFiveYearDetailList();
                        List<TrsFiveYearDetailEntity> trsFiveYearDetailEntityList = new ArrayList<>();
                        for (TrsFiveYearDetail trsFiveYearDetail : trsFiveYearDetailList) {
                            TrsFiveYearDetailEntity trsFiveYearDetailEntity = new TrsFiveYearDetailEntity();
                            BeanUtils.copyProperties(trsFiveYearDetail, trsFiveYearDetailEntity);
                            trsFiveYearDetailEntity.setName(commonParam.getName());
                            trsFiveYearDetailEntity.setIdNum(commonParam.getIdNum());
                            trsFiveYearDetailEntity.setHeadInfId(commonParam.getHeadInfId());
                            trsFiveYearDetailEntity.setRptNo(commonParam.getRptNo());
                            trsFiveYearDetailEntityList.add(trsFiveYearDetailEntity);

                        }
                        trsFiveYearDetailService.saveBatch(trsFiveYearDetailEntityList);
                    }
                }
                //特殊交易信息
                TrsSpecInf trsSpecInf = trsAcctInf.getTrsSpecInf();
                if (null != trsSpecInf) {
                    List<TrsSpecDetail> trsSpecDetailList = trsSpecInf.getTrsSpecDetailList();
                    List<TrsSpecEntity> trsSpecEntityList = new ArrayList<>();
                    for (TrsSpecDetail trsSpecDetail : trsSpecDetailList) {
                        TrsSpecEntity trsSpecEntity = new TrsSpecEntity();
                        BeanUtils.copyProperties(trsSpecDetail, trsSpecEntity);
                        trsSpecEntity.setName(commonParam.getName());
                        trsSpecEntity.setIdNum(commonParam.getIdNum());
                        trsSpecEntity.setHeadInfId(commonParam.getHeadInfId());
                        trsSpecEntity.setRptNo(commonParam.getRptNo());
                        trsSpecEntityList.add(trsSpecEntity);
                    }
                    trsSpecService.saveBatch(trsSpecEntityList);
                }
                //特殊事件说明信息
                TrsSpecEvtInf trsSpecEvtInf = trsAcctInf.getTrsSpecEvtInf();
                if (null != trsSpecEvtInf) {
                    List<TrsSpecEvtDetail> trsSpecEvtDetailList = trsSpecEvtInf.getTrsSpecEvtDetailList();
                    List<TrsSpecEvtEntity> trsSpecEvtEntityList = new ArrayList<>();
                    for (TrsSpecEvtDetail trsSpecEvtDetail : trsSpecEvtDetailList) {
                        TrsSpecEvtEntity trsSpecEvtEntity = new TrsSpecEvtEntity();
                        BeanUtils.copyProperties(trsSpecEvtDetail, trsSpecEvtEntity);
                        trsSpecEvtEntity.setName(commonParam.getName());
                        trsSpecEvtEntity.setIdNum(commonParam.getIdNum());
                        trsSpecEvtEntity.setHeadInfId(commonParam.getHeadInfId());
                        trsSpecEvtEntity.setRptNo(commonParam.getRptNo());
                        trsSpecEvtEntityList.add(trsSpecEvtEntity);
                    }
                    trsSpecEvtService.saveBatch(trsSpecEvtEntityList);
                }
                //大额专项分期信息段
                TrsSpecPrdInf trsSpecPrdInf = trsAcctInf.getTrsSpecPrdInf();
                if (null != trsSpecPrdInf) {
                    List<TrsSpecEvtDetail> trsSpecEvtDetailList = trsSpecPrdInf.getTrsSpecEvtDetailList();
                    List<TrsSpecPrdEntity> trsSpecPrdEntityList = new ArrayList<>();
                    for (TrsSpecEvtDetail trsSpecEvtDetail : trsSpecEvtDetailList) {
                        TrsSpecPrdEntity trsSpecPrdEntity = new TrsSpecPrdEntity();
                        BeanUtils.copyProperties(trsSpecEvtDetail, trsSpecPrdEntity);
                        trsSpecPrdEntity.setName(commonParam.getName());
                        trsSpecPrdEntity.setIdNum(commonParam.getIdNum());
                        trsSpecPrdEntity.setHeadInfId(commonParam.getHeadInfId());
                        trsSpecPrdEntity.setRptNo(commonParam.getRptNo());
                        trsSpecPrdEntityList.add(trsSpecPrdEntity);
                    }
                    trsSpecPrdService.saveBatch(trsSpecPrdEntityList);
                }

            }
        }
    }
}
