package com.kexun.utils;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;

import javax.xml.transform.*;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;
import java.io.StringReader;
import java.io.StringWriter;

/**
 * Description: 内容格式化工具类
 *
 * @author lgs
 * @date 2024/01/16
 */
public class FormartUtils {


    /**
     * 格式化XML内容
     *
     * @param xmlContext
     */
    public static String forMartXml(String xmlContext) {
        // 创建TransformerFactory
        TransformerFactory transformerFactory = TransformerFactory.newInstance();
        // 使用TransformerFactory创建一个Transformer
        Transformer transformer = null;
        try {
            transformer = transformerFactory.newTransformer();
        } catch (TransformerConfigurationException e) {
            e.printStackTrace();
        }
        // 设置输出属性，使输出的XML字符串带有结构
        transformer.setOutputProperty(OutputKeys.INDENT, "yes");
        transformer.setOutputProperty("{http://xml.apache.org/xslt}indent-amount", "2");
        // 将XML字符串转换为StreamSource
        StreamSource xmlSource = new StreamSource(new StringReader(xmlContext));
        // 创建一个StringWriter来保存格式化后的XML
        StringWriter stringWriter = new StringWriter();
        // 使用Transformer将XML格式化并写入StringWriter
        try {
            transformer.transform(xmlSource, new StreamResult(stringWriter));
        } catch (TransformerException e) {
            e.printStackTrace();
        }
        // 使用StringWriter的toString方法获取格式化后的XML字符串
        String formattedXml = stringWriter.toString();
        return formattedXml;
    }

    /**
     * 格式化JSON字符串
     *
     * @param jsonContext
     * @return
     */
    public static String formatJson(String jsonContext) {
        //json文件
        ObjectMapper objectMapper = new ObjectMapper();
        // 解析JSON字符串为JsonNode
        JsonNode jsonNode = null;
        String formattedJson = "";
        try {
            jsonNode = objectMapper.readTree(jsonContext);
            formattedJson = objectMapper.writerWithDefaultPrettyPrinter().writeValueAsString(jsonNode);
        } catch (JsonProcessingException e) {
            e.printStackTrace();
        }
        return formattedJson;
    }

}
